==> nicotine%2B-3.2.2-2-any.pkg.tar.xz: usr/lib/python3.10/site-packages/nicotine_plus-3.2.2.dist-info/AUTHORS.md <==
# Nicotine+ Team

## Active

### Mat (mathiascode)
 - Maintainer (2020–present)
 - Developer

### Kip Warner
 - Maintainer (2018–2020)
 - Developer
 - Debianization
 - [kip(at)thevertigo(dot)com]

### eLvErDe
 - Maintainer (2013–2016)
 - Domain name administrator
 - Source code migration from SVN to GitHub
 - Developer

### Han Boetes
 - Tester
 - Documentation
 - Bug hunting
 - Translation management

### alekksander
 - Tester
 - Redesign of some graphics

### slook
 - Tester
 - Accessibility improvements

## Retired

### daelstorm
 - Maintainer (2004–2009)
 - Developer
 - [daelstorm(at)gmail(dot)com]

### QuinoX
 - Maintainer (2009–2012)
 - Developer

### Michael Labouebe (aka gfarmerfr)
 - Maintainer (2016–2017)
 - Developer
 - [gfarmerfr(at)free(dot)fr]

### gallows (aka 'burp O')
 - Developer
 - Packager
 - Submitted Slack.Build file
 - [g4ll0ws(at)gmail(dot)com]

### hedonist (formerly known as alexbk)
 - OS X Nicotine.app maintainer / developer
 - Author of PySoulSeek, used for Nicotine core
 - [ak(at)sensi(dot)org]

### lee8oi
 - Bash commander
 - New and updated /alias
 - [winslaya(at)gmail(dot)com]

### INMCM
 - Nicotine+ topic maintainer on ubuntuforums.org
 - https://ubuntuforums.org/showthread.php?t=196835

### suser-guru
 - Suse Linux packager
 - https://dev-loki.blogspot.fr/
 - Nicotine+ RPM's for Suse 9.1, 9.2, 9.3, 10.0, 10.1

### osiris
 - Handy-man
 - Documentation
 - Some GNU/Linux packaging
 - Nicotine+ on Win32
 - Author of Nicotine+ guide
 - [osiris.contact(at)gmail(dot)com]

### Mutnick
 - Created Nicotine+ GitHub organization
 - Developer
 - [muhing(at)yahoo(dot)com]

### Lene Preuss
 - Python 3 migration
 - Unit and DEP-8 continuous integration testing
 - [lene.preuss(at)here(dot)com]

---

# Nicotine Team

## Retired

### Hyriand
 - Maintainer (2003–2004)
 - [hyriand(at)thegraveyard(dot)org]

### osiris
 - Handy-man
 - [osiris.contact(at)gmail(dot)com]

### SmackleFunky
 - Beta tester

### Wretched
 - Beta tester
 - Bringer of great ideas

### (va)\*10^3
 - Beta tester
 - Designer of Nicotine homepage and artwork (logos)

### sierracat
 - MacOSX tester
 - soulseeX developer

### Gustavo
 - Created the exception dialog
 - [gjc(at)inescporto(dot)pt]

### SeeSchloss
 - Developer
 - Created 1.0.8 Win32 installer
 - Created [Soulfind](https://github.com/seeschloss/soulfind), open source Soulseek server written in D

### vasi
 - Mac developer
 - Packaged Nicotine on OSX PowerPC
 - [djvasi(at)gmail(dot)com]

---

# PySoulSeek Contributors

## Retired

### Alexander Kanavin
 - Maintainer (2001–2005)
 - [ak(at)sensi(dot)org]

### Nir Arbel
 - Helped with many protocol questions I had, and of
   course he designed and implemented the whole
   system.
 - [nir(at)slsk(dot)org]

### Zip (Brett W. Thompson)
 - I used his client code to get an initial impression
   of how the system works.
 - Supplied the patch for logging chat conversations.
 - [brettt(at)tfn(dot)net]

### Josselin Mouette
 - Official Debian package maintainer
 - [joss(at)debian(dot)org]

### blueboy
 - Former unofficial Debian package maintainer
 - [bluegeek(at)eresmas(dot)com]

### Christian Swinehart
 - Fink package maintainer
 - [cswinehart(at)users(dot)sourceforge(dot)net]

### Hyriand
 - Patches for upload bandwidth management, banning,
   various UI improvements and more
 - [hyriand(at)thegraveyard(dot)org]

### Geert Kloosterman
 - A script for importing Windows Soulseek configuration
 - [geertk(at)ai(dot)rug(dot)nl]

### Joe Halliwell
 - Submitted a patch for optionally discarding search
   results after closing a search tab
 - [s9900164(at)sms(dot)ed(dot)ac(dot)uk]

### Alexey Vyskubov
 - Code cleanups
 - [alexey(dot)vyskubov(at)nokia(dot)com]

### Jason Green
 - Ignore list and auto-join checkbox, wishlists
 - [smacklefunky(at)optusnet(dot)com(dot)au]

---

# Third-Party Attributions

 - This program includes IP2Location LITE data available from:  
   https://lite.ip2location.com

 - Country flags licensed under the MIT License.  
   Copyright (c) 2016–2017 Bowtie AB  
   Copyright (c) 2018–2020 Jack Marsh  
   https://github.com/jackiboy/flagpack

 - tinytag licensed under the MIT License.  
   Copyright (c) 2014–2022 Tom Wallroth  
   https://github.com/devsnd/tinytag/

==> nicotine%2B-3.2.9-2-any.pkg.tar.xz: usr/lib/python3.11/site-packages/nicotine_plus-3.2.9.dist-info/AUTHORS.md <==
# Nicotine+ Team

## Active

### Mat (mathiascode)
 - Maintainer (2020–present)
 - Developer

### eLvErDe
 - Maintainer (2013–2016)
 - Domain name administrator
 - Source code migration from SVN to GitHub
 - Developer

### Han Boetes
 - Tester
 - Documentation
 - Bug hunting
 - Translation management

### alekksander
 - Tester
 - Redesign of some graphics

### slook
 - Tester
 - Accessibility improvements

## Inactive

### daelstorm
 - Maintainer (2004–2009)
 - Developer

### quinox
 - Maintainer (2009–2012)
 - Developer

### Michael Labouebe (gfarmerfr)
 - Maintainer (2016–2017)
 - Developer

### Kip Warner
 - Maintainer (2018–2020)
 - Developer
 - Debianization

### gallows (aka 'burp O')
 - Developer
 - Packager
 - Submitted Slack.Build file

### hedonist (formerly known as alexbk)
 - OS X Nicotine.app maintainer / developer
 - Author of PySoulSeek, used for Nicotine core

### lee8oi
 - Bash commander
 - New and updated /alias

### INMCM
 - Nicotine+ topic maintainer on [ubuntuforums.org](https://ubuntuforums.org/showthread.php?t=196835)

### suser-guru
 - Suse Linux packager
 - Nicotine+ RPM's for Suse 9.1, 9.2, 9.3, 10.0, 10.1

### osiris
 - Handy-man
 - Documentation
 - Some GNU/Linux packaging
 - Nicotine+ on Win32
 - Author of Nicotine+ guide

### Mutnick
 - Created Nicotine+ GitHub organization
 - Developer

### Lene Preuss
 - Python 3 migration
 - Unit and DEP-8 continuous integration testing

---

# Nicotine Team

### Ingmar K. Steen (Hyriand)
 - Maintainer (2003–2004)

### daelstorm
 - Beta tester
 - Designer of most of the settings
 - Made the Nicotine icons

### SmackleFunky
 - Beta tester

### Wretched
 - Beta tester
 - Bringer of great ideas

### (va)\*10^3
 - Beta tester
 - Designer of Nicotine homepage and artwork (logos)

### sierracat
 - MacOSX tester
 - soulseeX developer

### Gustavo J. A. M. Carneiro
 - Created the exception dialog

### SeeSchloss
 - Developer
 - Created 1.0.8 Win32 installer
 - Created [Soulfind](https://github.com/seeschloss/soulfind), open source Soulseek server written in D

### vasi
 - Mac developer
 - Packaged Nicotine on OSX PowerPC

---

# PySoulSeek Contributors

### Alexander Kanavin
 - Maintainer (2001–2003)

### Nir Arbel
 - Helped with many protocol questions I had, and of
   course he designed and implemented the whole
   system.

### Brett W. Thompson (Zip)
 - I used his client code to get an initial impression
   of how the system works.
 - Supplied the patch for logging chat conversations.

### Josselin Mouette
 - Official Debian package maintainer

### blueboy
 - Former unofficial Debian package maintainer

### Christian Swinehart
 - Fink package maintainer

### Ingmar K. Steen (Hyriand)
 - Patches for upload bandwidth management, banning,
   various UI improvements and more

### Geert Kloosterman
 - A script for importing Windows Soulseek configuration

### Joe Halliwell
 - Submitted a patch for optionally discarding search
   results after closing a search tab

### Alexey Vyskubov
 - Code cleanups

### Jason Green (SmackleFunky)
 - Ignore list and auto-join checkbox, wishlists

---

# Third-Party Attributions

 - This program includes IP2Location LITE data available from:  
   https://lite.ip2location.com

 - Country flags licensed under the MIT License.  
   Copyright (c) 2016–2017 Bowtie AB  
   Copyright (c) 2018–2020 Jack Marsh  
   https://github.com/jackiboy/flagpack

 - tinytag licensed under the MIT License.  
   Copyright (c) 2014–2022 Tom Wallroth  
   https://github.com/devsnd/tinytag/
